==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkIntersectionPolyDataFilter.java <==
// java wrapper for vtkIntersectionPolyDataFilter object
//

package vtk;
import vtk.*;

public class vtkIntersectionPolyDataFilter extends vtkPolyDataAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetNumberOfIntersectionPoints_2();
  public int GetNumberOfIntersectionPoints()
    { return GetNumberOfIntersectionPoints_2(); }

  private native int GetNumberOfIntersectionLines_3();
  public int GetNumberOfIntersectionLines()
    { return GetNumberOfIntersectionLines_3(); }

  private native int GetSplitFirstOutput_4();
  public int GetSplitFirstOutput()
    { return GetSplitFirstOutput_4(); }

  private native void SetSplitFirstOutput_5(int id0);
  public void SetSplitFirstOutput(int id0)
    { SetSplitFirstOutput_5(id0); }

  private native void SplitFirstOutputOn_6();
  public void SplitFirstOutputOn()
    { SplitFirstOutputOn_6(); }

  private native void SplitFirstOutputOff_7();
  public void SplitFirstOutputOff()
    { SplitFirstOutputOff_7(); }

  private native int GetSplitSecondOutput_8();
  public int GetSplitSecondOutput()
    { return GetSplitSecondOutput_8(); }

  private native void SetSplitSecondOutput_9(int id0);
  public void SetSplitSecondOutput(int id0)
    { SetSplitSecondOutput_9(id0); }

  private native void SplitSecondOutputOn_10();
  public void SplitSecondOutputOn()
    { SplitSecondOutputOn_10(); }

  private native void SplitSecondOutputOff_11();
  public void SplitSecondOutputOff()
    { SplitSecondOutputOff_11(); }

  private native int GetComputeIntersectionPointArray_12();
  public int GetComputeIntersectionPointArray()
    { return GetComputeIntersectionPointArray_12(); }

  private native void SetComputeIntersectionPointArray_13(int id0);
  public void SetComputeIntersectionPointArray(int id0)
    { SetComputeIntersectionPointArray_13(id0); }

  private native void ComputeIntersectionPointArrayOn_14();
  public void ComputeIntersectionPointArrayOn()
    { ComputeIntersectionPointArrayOn_14(); }

  private native void ComputeIntersectionPointArrayOff_15();
  public void ComputeIntersectionPointArrayOff()
    { ComputeIntersectionPointArrayOff_15(); }

  private native int GetCheckInput_16();
  public int GetCheckInput()
    { return GetCheckInput_16(); }

  private native void SetCheckInput_17(int id0);
  public void SetCheckInput(int id0)
    { SetCheckInput_17(id0); }

  private native void CheckInputOn_18();
  public void CheckInputOn()
    { CheckInputOn_18(); }

  private native void CheckInputOff_19();
  public void CheckInputOff()
    { CheckInputOff_19(); }

  private native int GetCheckMesh_20();
  public int GetCheckMesh()
    { return GetCheckMesh_20(); }

  private native void SetCheckMesh_21(int id0);
  public void SetCheckMesh(int id0)
    { SetCheckMesh_21(id0); }

  private native void CheckMeshOn_22();
  public void CheckMeshOn()
    { CheckMeshOn_22(); }

  private native void CheckMeshOff_23();
  public void CheckMeshOff()
    { CheckMeshOff_23(); }

  private native int GetStatus_24();
  public int GetStatus()
    { return GetStatus_24(); }

  private native double GetTolerance_25();
  public double GetTolerance()
    { return GetTolerance_25(); }

  private native void SetTolerance_26(double id0);
  public void SetTolerance(double id0)
    { SetTolerance_26(id0); }

  private native void CleanAndCheckSurface_27(vtkPolyData id0,double id1[],double id2);
  public void CleanAndCheckSurface(vtkPolyData id0,double id1[],double id2)
    { CleanAndCheckSurface_27(id0,id1,id2); }

  private native void CleanAndCheckInput_28(vtkPolyData id0,double id1);
  public void CleanAndCheckInput(vtkPolyData id0,double id1)
    { CleanAndCheckInput_28(id0,id1); }

  public vtkIntersectionPolyDataFilter() { super(); }

  public vtkIntersectionPolyDataFilter(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-armv7h.pkg.tar.xz: vtk/vtkIntersectionPolyDataFilter.java <==
// java wrapper for vtkIntersectionPolyDataFilter object
//

package vtk;
import vtk.*;

public class vtkIntersectionPolyDataFilter extends vtkPolyDataAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetNumberOfIntersectionPoints_2();
  public int GetNumberOfIntersectionPoints()
    { return GetNumberOfIntersectionPoints_2(); }

  private native int GetNumberOfIntersectionLines_3();
  public int GetNumberOfIntersectionLines()
    { return GetNumberOfIntersectionLines_3(); }

  private native int GetSplitFirstOutput_4();
  public int GetSplitFirstOutput()
    { return GetSplitFirstOutput_4(); }

  private native void SetSplitFirstOutput_5(int id0);
  public void SetSplitFirstOutput(int id0)
    { SetSplitFirstOutput_5(id0); }

  private native void SplitFirstOutputOn_6();
  public void SplitFirstOutputOn()
    { SplitFirstOutputOn_6(); }

  private native void SplitFirstOutputOff_7();
  public void SplitFirstOutputOff()
    { SplitFirstOutputOff_7(); }

  private native int GetSplitSecondOutput_8();
  public int GetSplitSecondOutput()
    { return GetSplitSecondOutput_8(); }

  private native void SetSplitSecondOutput_9(int id0);
  public void SetSplitSecondOutput(int id0)
    { SetSplitSecondOutput_9(id0); }

  private native void SplitSecondOutputOn_10();
  public void SplitSecondOutputOn()
    { SplitSecondOutputOn_10(); }

  private native void SplitSecondOutputOff_11();
  public void SplitSecondOutputOff()
    { SplitSecondOutputOff_11(); }

  private native int GetComputeIntersectionPointArray_12();
  public int GetComputeIntersectionPointArray()
    { return GetComputeIntersectionPointArray_12(); }

  private native void SetComputeIntersectionPointArray_13(int id0);
  public void SetComputeIntersectionPointArray(int id0)
    { SetComputeIntersectionPointArray_13(id0); }

  private native void ComputeIntersectionPointArrayOn_14();
  public void ComputeIntersectionPointArrayOn()
    { ComputeIntersectionPointArrayOn_14(); }

  private native void ComputeIntersectionPointArrayOff_15();
  public void ComputeIntersectionPointArrayOff()
    { ComputeIntersectionPointArrayOff_15(); }

  private native int GetCheckInput_16();
  public int GetCheckInput()
    { return GetCheckInput_16(); }

  private native void SetCheckInput_17(int id0);
  public void SetCheckInput(int id0)
    { SetCheckInput_17(id0); }

  private native void CheckInputOn_18();
  public void CheckInputOn()
    { CheckInputOn_18(); }

  private native void CheckInputOff_19();
  public void CheckInputOff()
    { CheckInputOff_19(); }

  private native int GetCheckMesh_20();
  public int GetCheckMesh()
    { return GetCheckMesh_20(); }

  private native void SetCheckMesh_21(int id0);
  public void SetCheckMesh(int id0)
    { SetCheckMesh_21(id0); }

  private native void CheckMeshOn_22();
  public void CheckMeshOn()
    { CheckMeshOn_22(); }

  private native void CheckMeshOff_23();
  public void CheckMeshOff()
    { CheckMeshOff_23(); }

  private native int GetStatus_24();
  public int GetStatus()
    { return GetStatus_24(); }

  private native double GetTolerance_25();
  public double GetTolerance()
    { return GetTolerance_25(); }

  private native void SetTolerance_26(double id0);
  public void SetTolerance(double id0)
    { SetTolerance_26(id0); }

  private native void CleanAndCheckSurface_27(vtkPolyData id0,double id1[],double id2);
  public void CleanAndCheckSurface(vtkPolyData id0,double id1[],double id2)
    { CleanAndCheckSurface_27(id0,id1,id2); }

  private native void CleanAndCheckInput_28(vtkPolyData id0,double id1);
  public void CleanAndCheckInput(vtkPolyData id0,double id1)
    { CleanAndCheckInput_28(id0,id1); }

  public vtkIntersectionPolyDataFilter() { super(); }

  public vtkIntersectionPolyDataFilter(long id) { super(id); }
  public native long   VTKInit();

}
